@@ -8,7 +8,7 @@
 
 QT_BEGIN_NAMESPACE
 
-using namespace qdesigner_internal;
+namespace qdesigner_internal {
 
 StringListEditorButton::StringListEditorButton(
     const QStringList &stringList, QWidget *parent)
@@ -38,4 +38,6 @@ void StringListEditorButton::showStringListEditor()
     }
 }
 
+} // namespace qdesigner_internal
+
 QT_END_NAMESPACE
