@@ -30,24 +30,24 @@ public:
     TreeWidgetContents contents() const;
 
 private slots:
-    void on_newItemButton_clicked();
-    void on_newSubItemButton_clicked();
-    void on_deleteItemButton_clicked();
-    void on_moveItemUpButton_clicked();
-    void on_moveItemDownButton_clicked();
-    void on_moveItemRightButton_clicked();
-    void on_moveItemLeftButton_clicked();
+    void newItemButtonClicked();
+    void newSubItemButtonClicked();
+    void deleteItemButtonClicked();
+    void moveItemUpButtonClicked();
+    void moveItemDownButtonClicked();
+    void moveItemRightButtonClicked();
+    void moveItemLeftButtonClicked();
 
-    void on_treeWidget_currentItemChanged();
-    void on_treeWidget_itemChanged(QTreeWidgetItem *item, int column);
+    void treeWidgetCurrentItemChanged();
+    void treeWidgetItemChanged(QTreeWidgetItem *item, int column);
 
-    void on_columnEditor_indexChanged(int idx);
-    void on_columnEditor_itemChanged(int idx, int role, const QVariant &v);
+    void columnEditorIndexChanged(int idx);
+    void columnEditorItemChanged(int idx, int role, const QVariant &v);
 
-    void on_columnEditor_itemInserted(int idx);
-    void on_columnEditor_itemDeleted(int idx);
-    void on_columnEditor_itemMovedUp(int idx);
-    void on_columnEditor_itemMovedDown(int idx);
+    void columnEditorItemInserted(int idx);
+    void columnEditorItemDeleted(int idx);
+    void columnEditorItemMovedUp(int idx);
+    void columnEditorItemMovedDown(int idx);
 
     void togglePropertyBrowser();
     void cacheReloaded();
