@@ -8,7 +8,7 @@
 #include "widgetfactory_p.h"
 #include "zoomwidget_p.h"
 
-#include <deviceskin.h>
+#include <deviceskin_p.h>
 
 #include <QtDesigner/abstractformeditor.h>
 #include <QtDesigner/abstractformwindow.h>
@@ -33,10 +33,13 @@
 #include <QtCore/qdebug.h>
 #include <QtCore/qlist.h>
 #include <QtCore/qmap.h>
+#include <QtCore/qpointer.h>
 #include <QtCore/qshareddata.h>
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 static inline int compare(const qdesigner_internal::PreviewConfiguration &pc1, const qdesigner_internal::PreviewConfiguration &pc2)
 {
     int rc = pc1.style().compare(pc2.style());
@@ -48,7 +51,7 @@ static inline int compare(const qdesigner_internal::PreviewConfiguration &pc1, c
     return pc1.deviceSkin().compare(pc2.deviceSkin());
 }
 
-namespace {
+namespace qdesigner_internal {
     // ------ PreviewData (data associated with a preview window)
     struct PreviewData {
         PreviewData(const QPointer<QWidget> &widget, const  QDesignerFormWindowInterface *formWindow, const qdesigner_internal::PreviewConfiguration &pc);
@@ -65,9 +68,6 @@ namespace {
         m_configuration(pc)
     {
     }
-}
-
-namespace qdesigner_internal {
 
 /* In designer, we have the situation that laid-out maincontainers have
  * a geometry set (which might differ from their sizeHint()). The QGraphicsItem
@@ -408,9 +408,9 @@ void ZoomablePreviewDeviceSkin::fitWidget(const QSize &size)
 
 // ------------- PreviewConfiguration
 
-static const char *styleKey = "Style";
-static const char *appStyleSheetKey = "AppStyleSheet";
-static const char *skinKey = "Skin";
+static constexpr auto styleKey = "Style"_L1;
+static constexpr auto appStyleSheetKey = "AppStyleSheet"_L1;
+static constexpr auto skinKey = "Skin"_L1;
 
 PreviewConfiguration::PreviewConfiguration() :
     m_d(new PreviewConfigurationData)
@@ -478,30 +478,29 @@ void PreviewConfiguration::toSettings(const QString &prefix, QDesignerSettingsIn
 {
     const PreviewConfigurationData &d = *m_d;
     settings->beginGroup(prefix);
-    settings->setValue(QLatin1String(styleKey),  d.m_style);
-    settings->setValue(QLatin1String(appStyleSheetKey), d.m_applicationStyleSheet);
-    settings->setValue(QLatin1String(skinKey), d.m_deviceSkin);
+    settings->setValue(styleKey, d.m_style);
+    settings->setValue(appStyleSheetKey, d.m_applicationStyleSheet);
+    settings->setValue(skinKey, d.m_deviceSkin);
     settings->endGroup();
 }
 
 void PreviewConfiguration::fromSettings(const QString &prefix, const QDesignerSettingsInterface *settings)
 {
     clear();
-    QString key = prefix;
-    key += QLatin1Char('/');
-    const int prefixSize = key.size();
+    QString key = prefix + u'/';
+    const auto prefixSize = key.size();
 
     PreviewConfigurationData &d = *m_d;
 
     const QVariant emptyString = QVariant(QString());
 
-    key += QLatin1String(styleKey);
+    key += styleKey;
     d.m_style = settings->value(key, emptyString).toString();
 
-    key.replace(prefixSize, key.size() - prefixSize, QLatin1String(appStyleSheetKey));
+    key.replace(prefixSize, key.size() - prefixSize, appStyleSheetKey);
     d.m_applicationStyleSheet = settings->value(key, emptyString).toString();
 
-    key.replace(prefixSize, key.size() - prefixSize, QLatin1String(skinKey));
+    key.replace(prefixSize, key.size() - prefixSize, skinKey);
     d.m_deviceSkin = settings->value(key, emptyString).toString();
 }
 
@@ -534,8 +533,7 @@ public:
 
     PreviewDataList m_previews;
 
-    typedef QMap<QString, DeviceSkinParameters> DeviceSkinConfigCache;
-    DeviceSkinConfigCache m_deviceSkinConfigCache;
+    QMap<QString, DeviceSkinParameters> m_deviceSkinConfigCache;
 
     QDesignerFormEditorInterface *m_core;
     bool m_updateBlocked;
@@ -678,7 +676,7 @@ QWidget *PreviewManager::createPreview(const QDesignerFormWindowInterface *fw,
         return formWidget;
     }
     // Embed into skin. find config in cache
-    PreviewManagerPrivate::DeviceSkinConfigCache::iterator it = d->m_deviceSkinConfigCache.find(deviceSkin);
+    auto it = d->m_deviceSkinConfigCache.find(deviceSkin);
     if (it == d->m_deviceSkinConfigCache.end()) {
         DeviceSkinParameters parameters;
         if (!parameters.read(deviceSkin, DeviceSkinParameters::ReadAll, errorMessage)) {
@@ -771,15 +769,13 @@ QWidget *PreviewManager::showPreview(const QDesignerFormWindowInterface *fw,
 
 QWidget *PreviewManager::raise(const QDesignerFormWindowInterface *fw, const PreviewConfiguration &pc)
 {
-    using PreviewDataList = PreviewManagerPrivate::PreviewDataList;
     if (d->m_previews.isEmpty())
         return nullptr;
 
     // find matching window
-    const PreviewDataList::const_iterator cend =  d->m_previews.constEnd();
-    for (PreviewDataList::const_iterator it = d->m_previews.constBegin(); it !=  cend ;++it) {
-        QWidget * w = it->m_widget;
-        if (w && it->m_formWindow == fw && it->m_configuration == pc) {
+    for (const auto &pd : std::as_const(d->m_previews)) {
+        QWidget *w = pd.m_widget;
+        if (w && pd.m_formWindow == fw && pd.m_configuration == pc) {
             w->raise();
             w->activateWindow();
             return w;
@@ -793,9 +789,9 @@ void PreviewManager::closeAllPreviews()
     if (!d->m_previews.isEmpty()) {
         d->m_updateBlocked = true;
         d->m_activePreview = nullptr;
-        for (auto it = d->m_previews.constBegin(), cend = d->m_previews.constEnd(); it != cend ;++it) {
-            if (it->m_widget)
-                it->m_widget->close();
+        for (const auto &pd : std::as_const(d->m_previews)) {
+            if (pd.m_widget)
+                pd.m_widget->close();
         }
         d->m_previews.clear();
         d->m_updateBlocked = false;
@@ -805,11 +801,10 @@ void PreviewManager::closeAllPreviews()
 
 void PreviewManager::updatePreviewClosed(QWidget *w)
 {
-    using PreviewDataList = PreviewManagerPrivate::PreviewDataList;
     if (d->m_updateBlocked)
         return;
     // Purge out all 0 or widgets to be deleted
-    for (PreviewDataList::iterator it = d->m_previews.begin(); it != d->m_previews.end() ; ) {
+    for (auto it = d->m_previews.begin(); it != d->m_previews.end() ; ) {
         QWidget *iw = it->m_widget; // Might be 0 when catching QEvent::Destroyed
         if (iw == nullptr || iw == w) {
             it = d->m_previews.erase(it);
