@@ -8,7 +8,7 @@
 
 QT_BEGIN_NAMESPACE
 
-using namespace qdesigner_internal;
+namespace qdesigner_internal {
 
 /*!
     \class qdesigner_internal::QDesignerFormWindowManager
@@ -46,4 +46,6 @@ void QDesignerFormWindowManager::showPluginDialog()
     dlg.exec();
 }
 
+} // namespace qdesigner_internal
+
 QT_END_NAMESPACE
