@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qquickwidget_plugin.h"
 
@@ -15,6 +15,8 @@
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 QQuickWidgetPlugin::QQuickWidgetPlugin(QObject *parent)
     : QObject(parent)
 {
@@ -22,17 +24,17 @@ QQuickWidgetPlugin::QQuickWidgetPlugin(QObject *parent)
 
 QString QQuickWidgetPlugin::name() const
 {
-    return QStringLiteral("QQuickWidget");
+    return u"QQuickWidget"_s;
 }
 
 QString QQuickWidgetPlugin::group() const
 {
-    return QStringLiteral("Display Widgets");
+    return u"Display Widgets"_s;
 }
 
 QString QQuickWidgetPlugin::toolTip() const
 {
-    return QStringLiteral("A widget for displaying a Qt Quick 2 user interface.");
+    return u"A widget for displaying a Qt Quick 2 user interface."_s;
 }
 
 QString QQuickWidgetPlugin::whatsThis() const
@@ -42,12 +44,12 @@ QString QQuickWidgetPlugin::whatsThis() const
 
 QString QQuickWidgetPlugin::includeFile() const
 {
-    return QStringLiteral("<QtQuickWidgets/QQuickWidget>");
+    return u"<QtQuickWidgets/QQuickWidget>"_s;
 }
 
 QIcon QQuickWidgetPlugin::icon() const
 {
-    return QIcon(QStringLiteral(":/qt-project.org/qquickwidget/images/qquickwidget.png"));
+    return QIcon(u":/qt-project.org/qquickwidget/images/qquickwidget.png"_s);
 }
 
 bool QQuickWidgetPlugin::isContainer() const
@@ -57,13 +59,6 @@ bool QQuickWidgetPlugin::isContainer() const
 
 QWidget *QQuickWidgetPlugin::createWidget(QWidget *parent)
 {
-    const auto graphicsApi = QQuickWindow::graphicsApi();
-    if (graphicsApi != QSGRendererInterface::OpenGL) {
-        qWarning("Qt Designer: The QQuickWidget custom widget plugin is disabled because it requires OpenGL RHI (current: %d).",
-             int(graphicsApi));
-        return {};
-    }
-
     QQuickWidget *result = new QQuickWidget(parent);
     connect(result, &QQuickWidget::sceneGraphError,
             this, &QQuickWidgetPlugin::sceneGraphError);
@@ -85,9 +80,6 @@ void QQuickWidgetPlugin::initialize(QDesignerFormEditorInterface * /*core*/)
 
 QString QQuickWidgetPlugin::domXml() const
 {
-    if (QQuickWindow::graphicsApi() != QSGRendererInterface::OpenGL)
-        return {};
-
     return QStringLiteral(R"(
 <ui language="c++">
     <widget class="QQuickWidget" name="quickWidget">
