@@ -724,6 +724,24 @@ void LupdateVisitor::processPreprocessorCalls()
             processPreprocessorCall(store);
     }
 
+    // Processing the isolated comments (TRANSLATOR) in the files included in the main input file.
+#if (LUPDATE_CLANG_VERSION >= LUPDATE_CLANG_VERSION_CHECK(14,0,0))
+    for (const clang::FileEntry *file : m_preprocessor->getIncludedFiles()) {
+        auto &sourceMgr = m_context->getSourceManager();
+
+        clang::StringRef fileNameRealPath = file->tryGetRealPathName();
+        if (!LupdatePrivate::isFileSignificant(fileNameRealPath.str())
+                || fileNameRealPath.str() == m_inputFile)
+            continue;
+
+        auto sourceFile = sourceMgr.getFileManager()
+            .getFile(fileNameRealPath);
+        auto sourceLocation = sourceMgr.translateFileLineCol(sourceFile.get(), 1, 1);
+        const clang::FileID fileId = sourceMgr.getDecomposedLoc(sourceLocation).first;
+        processIsolatedComments(fileId);
+    }
+#endif
+
     if (m_qDeclareTrMacroAll.size() > 0 || m_noopTranslationMacroAll.size() > 0)
         m_macro = true;
 }
@@ -738,12 +756,14 @@ void LupdateVisitor::processPreprocessorCall(TranslationRelatedStore store)
         setInfoFromRawComment(rawComment, &store);
 
     // Processing the isolated comments (TRANSLATOR) in the files included in the main input file.
+#if (LUPDATE_CLANG_VERSION < LUPDATE_CLANG_VERSION_CHECK(14,0,0))
     if (store.callType.contains(QStringLiteral("InclusionDirective"))) {
         auto &sourceMgr = m_context->getSourceManager();
         const clang::FileID file = sourceMgr.getDecomposedLoc(store.callLocation(sourceMgr)).first;
         processIsolatedComments(file);
         return;
     }
+#endif
 
     if (store.isValid()) {
         if (store.funcName.contains(QStringLiteral("Q_DECLARE_TR_FUNCTIONS")))
@@ -762,12 +782,18 @@ bool LupdateVisitor::VisitNamedDecl(clang::NamedDecl *namedDeclaration)
     if (!fullLocation.isValid() || !fullLocation.getFileEntry())
         return true;
 
+#if (LUPDATE_CLANG_VERSION >= LUPDATE_CLANG_VERSION_CHECK(18,0,0))
+    auto fileEntry = fullLocation.getFileEntryRef();
+    if (fileEntry && !LupdatePrivate::isFileSignificant(fileEntry->getName().str()))
+        return true;
+#else
     if (!LupdatePrivate::isFileSignificant(fullLocation.getFileEntry()->getName().str()))
         return true;
+#endif
 
-    qCDebug(lcClang) << "NamedDecl Name:   " << namedDeclaration->getQualifiedNameAsString();
-    qCDebug(lcClang) << "NamedDecl source: " << namedDeclaration->getSourceRange().printToString(
-        m_context->getSourceManager());
+    qCDebug(lcClang) << "NamedDecl Name:   " << QString::fromStdString(namedDeclaration->getQualifiedNameAsString());
+    qCDebug(lcClang) << "NamedDecl source: " << QString::fromStdString(namedDeclaration->getSourceRange().printToString(
+        m_context->getSourceManager()));
     // Checks if there is a macro located within the range of this NamedDeclaration
     // in order to find a context for the macro
     findContextForTranslationStoresFromPP(namedDeclaration);
@@ -795,15 +821,15 @@ void LupdateVisitor::findContextForTranslationStoresFromPP(clang::NamedDecl *nam
 
             store.contextRetrieved = LupdatePrivate::contextForNoopMacro(namedDeclaration, sm);
             qCDebug(lcClang) << "------------------------------------------NOOP Macro in range ---";
-            qCDebug(lcClang) << "Range " << namedDeclaration->getSourceRange().printToString(sm);
-            qCDebug(lcClang) << "Point " << sourceLoc.printToString(sm);
+            qCDebug(lcClang) << "Range " << QString::fromStdString(namedDeclaration->getSourceRange().printToString(sm));
+            qCDebug(lcClang) << "Point " << QString::fromStdString(sourceLoc.printToString(sm));
             qCDebug(lcClang) << "=========== Visit Named Declaration =============================";
             qCDebug(lcClang) << " Declaration Location    " <<
-                namedDeclaration->getSourceRange().printToString(sm);
+                QString::fromStdString(namedDeclaration->getSourceRange().printToString(sm));
             qCDebug(lcClang) << " Macro       Location                                 "
-                << sourceLoc.printToString(sm);
+                << QString::fromStdString(sourceLoc.printToString(sm));
             qCDebug(lcClang) << " Context namedDeclaration->getQualifiedNameAsString() "
-                << namedDeclaration->getQualifiedNameAsString();
+                << QString::fromStdString(namedDeclaration->getQualifiedNameAsString());
             qCDebug(lcClang) << " Context LupdatePrivate::contextForNoopMacro          "
                 << store.contextRetrieved;
             qCDebug(lcClang) << " Context Retrieved       " << store.contextRetrieved;
@@ -820,13 +846,13 @@ void LupdateVisitor::findContextForTranslationStoresFromPP(clang::NamedDecl *nam
             store.contextRetrieved = QString::fromStdString(
                 namedDeclaration->getQualifiedNameAsString());
             qCDebug(lcClang) << "------------------------------------------DECL Macro in range ---";
-            qCDebug(lcClang) << "Range " << namedDeclaration->getSourceRange().printToString(sm);
-            qCDebug(lcClang) << "Point " << sourceLoc.printToString(sm);
+            qCDebug(lcClang) << "Range " << QString::fromStdString(namedDeclaration->getSourceRange().printToString(sm));
+            qCDebug(lcClang) << "Point " << QString::fromStdString(sourceLoc.printToString(sm));
             qCDebug(lcClang) << "=========== Visit Named Declaration =============================";
             qCDebug(lcClang) << " Declaration Location    " <<
-                namedDeclaration->getSourceRange().printToString(sm);
+                QString::fromStdString(namedDeclaration->getSourceRange().printToString(sm));
             qCDebug(lcClang) << " Macro       Location                                 "
-                << sourceLoc.printToString(sm);
+                << QString::fromStdString(sourceLoc.printToString(sm));
             qCDebug(lcClang) << " Context namedDeclaration->getQualifiedNameAsString() "
                 << store.contextRetrieved;
             qCDebug(lcClang) << " Context Retrieved       " << store.contextRetrieved;
