@@ -5,10 +5,11 @@
 #define FILESIGNIFICANCECHECK_H
 
 #include <QtCore/qdir.h>
+#include <QtCore/qreadwritelock.h>
 #include <QtCore/qregularexpression.h>
 #include <QtCore/qstringlist.h>
+#include <QtCore/qvector.h>
 
-#include <shared_mutex>
 #include <string>
 #include <unordered_map>
 #include <vector>
@@ -37,16 +38,16 @@ public:
     }
 
     void setRootDirectories(const QStringList &paths);
-    void setExclusionPatterns(const QStringList &patterns);
+    void setExclusionRegExes(const QVector<QRegularExpression> &expressions);
 
     bool isFileSignificant(const std::string &filePath) const;
 
 private:
     static FileSignificanceCheck *m_instance;
     std::vector<QDir> m_rootDirs;
-    std::vector<QRegularExpression> m_exclusionRegExes;
+    QVector<QRegularExpression> m_exclusionRegExes;
     mutable std::unordered_map<std::string, bool> m_cache;
-    mutable std::shared_mutex m_cacheMutex;
+    mutable QReadWriteLock m_cacheLock;
 };
 
 namespace LupdatePrivate {
