@@ -146,7 +146,7 @@ QString ParserTool::transcode(const QString &str)
     QByteArray out;
 
     out.reserve(in.size());
-    for (int i = 0; i < in.size();) {
+    for (qsizetype i = 0; i < in.size();) {
         uchar c = in[i++];
         if (c == '\\') {
             if (i >= in.size())
@@ -157,9 +157,16 @@ QString ParserTool::transcode(const QString &str)
                 continue;
 
             if (c == 'x' || c == 'u' || c == 'U') {
+                qsizetype maxSize = 2; // \x
+                if (c == 'u')
+                    maxSize = 4;
+                else if (c == 'U')
+                    maxSize = 8;
+                maxSize = std::min(in.size(), i + maxSize);
+
                 const bool unicode = (c != 'x');
                 QByteArray hex;
-                while (i < in.size() && isxdigit((c = in[i]))) {
+                while (i < maxSize && isxdigit((c = in[i]))) {
                     hex += c;
                     i++;
                 }
@@ -200,6 +207,25 @@ static void printErr(const QString & out)
     std::cerr << qPrintable(out);
 }
 
+static void printWarning(UpdateOptions options,
+                         const QString &msg,
+                         const QString &warningMsg = {},
+                         const QString &errorMsg = {})
+{
+    QString text = msg;
+    if (options & Werror) {
+        text.prepend("lupdate error: "_L1);
+        if (!errorMsg.isEmpty())
+            text.append(" "_L1).append(errorMsg);
+    } else {
+        text.prepend("lupdate warning: "_L1);
+        if (!warningMsg.isEmpty())
+            text.append(" "_L1).append(warningMsg);
+    }
+
+    printErr(text);
+}
+
 static void recursiveFileInfoList(const QDir &dir,
     const QSet<QString> &nameFilters, QDir::Filters filter,
     QFileInfoList *fileinfolist)
@@ -241,6 +267,8 @@ static void printUsage()
         "           Do not recursively scan directories.\n"
         "    -recursive\n"
         "           Recursively scan directories (default).\n"
+        "    -warnings-are-errors\n"
+        "           Treat warnings as errors.\n"
         "    -I <includepath> or -I<includepath>\n"
         "           Additional location to look for include files.\n"
         "           May be specified multiple times.\n"
@@ -342,11 +370,13 @@ static void updateTsFiles(const Translator &fetchedTor, const QStringList &tsFil
 {
     for (int i = 0; i < fetchedTor.messageCount(); i++) {
         const TranslatorMessage &msg = fetchedTor.constMessage(i);
-        if (!msg.id().isEmpty() && msg.sourceText().isEmpty())
-            printErr(QStringLiteral("lupdate warning: Message with id '%1' has no source.\n")
-                     .arg(msg.id()));
+        if (!msg.id().isEmpty() && msg.sourceText().isEmpty()) {
+            printWarning(options,
+                         "Message with id '%1' has no source.\n"_L1.arg(msg.id()));
+            if (options & Werror)
+                return;
+        }
     }
-
     QList<Translator> aliens;
     for (const QString &fileName : alienFiles) {
         ConversionData cd;
@@ -359,7 +389,6 @@ static void updateTsFiles(const Translator &fetchedTor, const QStringList &tsFil
         tor.resolveDuplicates();
         aliens << tor;
     }
-
     QDir dir;
     QString err;
     for (const QString &fileName : tsFileNames) {
@@ -375,17 +404,34 @@ static void updateTsFiles(const Translator &fetchedTor, const QStringList &tsFil
             }
             tor.resolveDuplicates();
             cd.clearErrors();
-            if (!targetLanguage.isEmpty() && targetLanguage != tor.languageCode())
-                printErr(QStringLiteral("lupdate warning: Specified target language '%1' disagrees with"
-                                " existing file's language '%2'. Ignoring.\n")
-                         .arg(targetLanguage, tor.languageCode()));
-            if (!sourceLanguage.isEmpty() && sourceLanguage != tor.sourceLanguageCode())
-                printErr(QStringLiteral("lupdate warning: Specified source language '%1' disagrees with"
-                                " existing file's language '%2'. Ignoring.\n")
-                         .arg(sourceLanguage, tor.sourceLanguageCode()));
+            if (!targetLanguage.isEmpty() && targetLanguage != tor.languageCode()) {
+                printWarning(options,
+                             "Specified target language '%1' disagrees with"
+                                            " existing file's language '%2'.\n"_L1
+                                     .arg(targetLanguage, tor.languageCode()),
+                             u"Ignoring.\n"_s);
+                if (options & Werror)
+                    return;
+            }
+            if (!sourceLanguage.isEmpty() && sourceLanguage != tor.sourceLanguageCode()) {
+                printWarning(options,
+                             "Specified source language '%1' disagrees with"
+                                     " existing file's language '%2'.\n"_L1
+                                     .arg(sourceLanguage, tor.sourceLanguageCode()),
+                             u"Ignoring.\n"_s);
+                if (options & Werror)
+                    return;
+            }
             // If there is translation in the file, the language should be recognized
             // (when the language is not recognized, plural translations are lost)
             if (tor.translationsExist()) {
+
+                if (tor.languageCode().isEmpty()) {
+                    printErr("File %1 won't be updated: it does not specify any "
+                             "target languages. To set a target language, open "
+                             "the file in Qt Linguist.\n"_L1.arg(fileName));
+                    continue;
+                }
                 QLocale::Language l;
                 QLocale::Territory c;
                 tor.languageAndTerritory(tor.languageCode(), &l, &c);
@@ -541,8 +587,8 @@ static bool processTs(Translator &fetchedTor, const QString &file, ConversionDat
     return false;
 }
 
-static void processSources(Translator &fetchedTor,
-                           const QStringList &sourceFiles, ConversionData &cd, bool *fail)
+static void processSources(Translator &fetchedTor, const QStringList &sourceFiles,
+                           ConversionData &cd, UpdateOptions options, bool *fail)
 {
 #ifdef QT_NO_QML
     bool requireQmlSupport = false;
@@ -556,13 +602,16 @@ static void processSources(Translator &fetchedTor,
             loadUI(fetchedTor, sourceFile, cd);
 #ifndef QT_NO_QML
         else if (sourceFile.endsWith(QLatin1String(".js"), Qt::CaseInsensitive)
-                 || sourceFile.endsWith(QLatin1String(".qs"), Qt::CaseInsensitive))
+                 || sourceFile.endsWith(QLatin1String(".qs"), Qt::CaseInsensitive)) {
             loadQScript(fetchedTor, sourceFile, cd);
-        else if (sourceFile.endsWith(QLatin1String(".qml"), Qt::CaseInsensitive))
+        } else if (sourceFile.endsWith(QLatin1String(".mjs"), Qt::CaseInsensitive)) {
+            loadJSModule(fetchedTor, sourceFile, cd);
+        } else if (sourceFile.endsWith(QLatin1String(".qml"), Qt::CaseInsensitive))
             loadQml(fetchedTor, sourceFile, cd);
 #else
         else if (sourceFile.endsWith(QLatin1String(".qml"), Qt::CaseInsensitive)
                  || sourceFile.endsWith(QLatin1String(".js"), Qt::CaseInsensitive)
+                 || sourceFile.endsWith(QLatin1String(".mjs"), Qt::CaseInsensitive)
                  || sourceFile.endsWith(QLatin1String(".qs"), Qt::CaseInsensitive))
             requireQmlSupport = true;
 #endif // QT_NO_QML
@@ -573,8 +622,14 @@ static void processSources(Translator &fetchedTor,
     }
 
 #ifdef QT_NO_QML
-    if (requireQmlSupport)
-        printErr(QStringLiteral("lupdate warning: Some files have been ignored due to missing qml/javascript support\n"));
+    if (requireQmlSupport) {
+        printWarning(options, u"missing qml/javascript support\n"_s,
+                     u"Some files have been ignored.\n"_s);
+        if (options & Werror)
+            return;
+    }
+#else
+    Q_UNUSED(options)
 #endif
 
     if (useClangToParseCpp) {
@@ -627,9 +682,11 @@ public:
     }
 
 private:
+
     void processProject(UpdateOptions options, const Project &prj, bool topLevel,
                         bool nestComplain, Translator *parentTor, bool *fail) const
     {
+
         QString codecForSource = prj.codec.toLower();
         if (!codecForSource.isEmpty()) {
             if (codecForSource == QLatin1String("utf-16")
@@ -639,8 +696,12 @@ private:
                        || codecForSource == QLatin1String("utf8")) {
                 options &= ~SourceIsUtf16;
             } else {
-                printErr(QStringLiteral("lupdate warning: Codec for source '%1' is invalid."
-                                " Falling back to UTF-8.\n").arg(codecForSource));
+                printWarning(
+                        options,
+                        "Codec for source '%1' is invalid.\n"_L1.arg(codecForSource),
+                        u"Falling back to UTF-8.\n"_s);
+                if (options & Werror)
+                    return;
                 options &= ~SourceIsUtf16;
             }
         }
@@ -667,12 +728,17 @@ private:
             tsFiles = *prj.translations;
             if (parentTor) {
                 if (topLevel) {
-                    printErr(QStringLiteral("lupdate warning: TS files from command line "
-                                    "will override TRANSLATIONS in %1.\n").arg(projectFile));
+                    printWarning(options, u"Existing top level."_s,
+                                 "TS files from command line will "
+                                 "override TRANSLATIONS in %1.\n"_L1.arg(projectFile),
+                                 u"Terminating the operation.\n"_s);
+                    if (options & Werror)
+                        return;
                     goto noTrans;
                 } else if (nestComplain) {
-                    printErr(QStringLiteral("lupdate warning: TS files from command line "
-                                    "prevent recursing into %1.\n").arg(projectFile));
+                    printWarning(options,
+                                "TS files from command line "
+                                "prevent recursing into %1.\n"_L1.arg(projectFile));
                     return;
                 }
             }
@@ -684,24 +750,29 @@ private:
             }
             Translator tor;
             processProjects(false, options, prj.subProjects, false, &tor, fail);
-            processSources(tor, sources, cd, fail);
+            processSources(tor, sources, cd, options, fail);
             updateTsFiles(tor, tsFiles, QStringList(), m_sourceLanguage, m_targetLanguage,
                           options, fail);
             return;
         }
 
+
       noTrans:
+
         if (!parentTor) {
             if (topLevel) {
-                printErr(QStringLiteral("lupdate warning: no TS files specified. Only diagnostics "
-                                "will be produced for '%1'.\n").arg(projectFile));
+                printWarning(options, u"no TS files specified."_s,
+                             "Only diagnostics will be produced for %1.\n"_L1.arg(projectFile),
+                             u"Terminating the operation.\n"_s);
+                if (options & Werror)
+                    return;
             }
             Translator tor;
             processProjects(false, options, prj.subProjects, nestComplain, &tor, fail);
-            processSources(tor, sources, cd, fail);
+            processSources(tor, sources, cd, options, fail);
         } else {
             processProjects(false, options, prj.subProjects, nestComplain, parentTor, fail);
-            processSources(*parentTor, sources, cd, fail);
+            processSources(*parentTor, sources, cd, options, fail);
         }
     }
 
@@ -726,7 +797,8 @@ int main(int argc, char **argv)
 #endif // Q_OS_WIN32
 #endif
 
-    m_defaultExtensions = QLatin1String("java,jui,ui,c,c++,cc,cpp,cxx,ch,h,h++,hh,hpp,hxx,js,qs,qml,qrc");
+    m_defaultExtensions = QLatin1String("java,jui,ui,c,c++,cc,cpp,cxx,ch,h,"_L1
+                                        "h++,hh,hpp,hxx,js,mjs,qs,qml,qrc"_L1);
 
     QStringList args = app.arguments();
     QStringList tsFileNames;
@@ -750,6 +822,8 @@ int main(int argc, char **argv)
     bool metXTsFlag = false;
     bool recursiveScan = true;
 
+    bool fail = false;
+
     QString extensions = m_defaultExtensions;
     QSet<QString> extensionsNameFilters;
 
@@ -843,6 +917,9 @@ int main(int argc, char **argv)
         } else if (arg == QLatin1String("-verbose")) {
             options |= Verbose;
             continue;
+        } else if (arg == QLatin1String("-warnings-are-errors")) {
+            options |= Werror;
+            continue;
         } else if (arg == QLatin1String("-no-recursive")) {
             recursiveScan = false;
             continue;
@@ -921,8 +998,7 @@ int main(int argc, char **argv)
                  commandLineCompilationDatabaseDir = args[i];
              }
             continue;
-        }
-        else if (arg == QLatin1String("-project-roots")) {
+        } else if (arg == QLatin1String("-project-roots")) {
             while ((i + 1) != argc && !args[i + 1].startsWith(QLatin1String("-"))) {
                  i++;
                  rootDirs << args[i];
@@ -969,8 +1045,11 @@ int main(int argc, char **argv)
                         if (!fi.exists() || fi.isWritable()) {
                             tsFileNames.append(QFileInfo(file).absoluteFilePath());
                         } else {
-                            printErr(QStringLiteral("lupdate warning: For some reason, '%1' is not writable.\n")
-                                     .arg(file));
+                            printWarning(options,
+                                         "For some reason, '%1' is not writable.\n"_L1
+                                                 .arg(file));
+                            if (options & Werror)
+                                return 1;
                         }
                         found = true;
                         break;
@@ -1025,6 +1104,7 @@ int main(int argc, char **argv)
                                     && !fn.endsWith(QLatin1String(".jui"))
                                     && !fn.endsWith(QLatin1String(".ui"))
                                     && !fn.endsWith(QLatin1String(".js"))
+                                    && !fn.endsWith(QLatin1String(".mjs"))
                                     && !fn.endsWith(QLatin1String(".qs"))
                                     && !fn.endsWith(QLatin1String(".qml"))) {
                                 int offset = 0;
@@ -1055,9 +1135,12 @@ int main(int argc, char **argv)
         return 1;
     }
 
-    if (!targetLanguage.isEmpty() && tsFileNames.size() != 1)
-        printErr(u"lupdate warning: -target-language usually only"
-                  " makes sense with exactly one TS file.\n"_s);
+    if (!targetLanguage.isEmpty() && tsFileNames.size() != 1) {
+        printWarning(options,
+                     u"-target-language usually only makes sense with exactly one TS file.\n"_s);
+        if (options & Werror)
+            return 1;
+    }
 
     if (proFiles.isEmpty() && resourceFiles.isEmpty() && sourceFiles.size() == 1
         && QFileInfo(sourceFiles.first()).fileName() == u"CMakeLists.txt"_s) {
@@ -1091,11 +1174,14 @@ int main(int argc, char **argv)
             expandQrcFiles(project);
     }
 
-    bool fail = false;
     if (projectDescription.empty()) {
-        if (tsFileNames.isEmpty())
-            printErr(u"lupdate warning:"
-                      " no TS files specified. Only diagnostics will be produced.\n"_s);
+        if (tsFileNames.isEmpty()) {
+            printWarning(options, u"no TS files specified."_s,
+                         u"Only diagnostics will be produced.\n"_s,
+                         u"Terminating the operation.\n"_s);
+            if (options & Werror)
+                return 1;
+        }
 
         Translator fetchedTor;
         ConversionData cd;
@@ -1108,7 +1194,7 @@ int main(int argc, char **argv)
         cd.m_rootDirs = rootDirs;
         for (const QString &resource : std::as_const(resourceFiles))
             sourceFiles << getResources(resource);
-        processSources(fetchedTor, sourceFiles, cd, &fail);
+        processSources(fetchedTor, sourceFiles, cd, options, &fail);
         updateTsFiles(fetchedTor, tsFileNames, alienFiles,
                       sourceLanguage, targetLanguage, options, &fail);
     } else {
