@@ -267,9 +267,11 @@ void Aggregate::resolveRelates()
  */
 void Aggregate::normalizeOverloads()
 {
-    for (auto map_it = m_functionMap.begin(); map_it != m_functionMap.end(); ++map_it) {
-        if ((*map_it).size() > 1) {
-            std::sort((*map_it).begin(), (*map_it).end(),
+    for (auto &map_it : m_functionMap) {
+        if (map_it.size() == 1) {
+            map_it.front()->setOverloadNumber(0);
+        } else if (map_it.size() > 1) {
+            std::sort(map_it.begin(), map_it.end(),
                 [](const FunctionNode *f1, const FunctionNode *f2) -> bool {
                     if (f1->isInternal() != f2->isInternal())
                         return f2->isInternal();
@@ -282,7 +284,7 @@ void Aggregate::normalizeOverloads()
             });
             // Set overload numbers
             signed short n{0};
-            for (auto *fn : (*map_it))
+            for (auto *fn : map_it)
                 fn->setOverloadNumber(n++);
         }
     }
@@ -301,13 +303,11 @@ void Aggregate::normalizeOverloads()
 const NodeList &Aggregate::nonfunctionList()
 {
     m_nonfunctionList = m_nonfunctionMap.values();
-    // Erase duplicates
-    std::sort(m_nonfunctionList.begin(), m_nonfunctionList.end());
-    m_nonfunctionList.erase(std::unique(m_nonfunctionList.begin(), m_nonfunctionList.end()),
-                            m_nonfunctionList.end());
-
     // Sort based on node name
     std::sort(m_nonfunctionList.begin(), m_nonfunctionList.end(), Node::nodeNameLessThan);
+    // Erase duplicates
+    m_nonfunctionList.erase(std::unique(m_nonfunctionList.begin(), m_nonfunctionList.end()),
+                            m_nonfunctionList.end());
     return m_nonfunctionList;
 }
 
@@ -690,30 +690,34 @@ void Aggregate::resolveQmlInheritance()
 
 /*!
   Returns a word representing the kind of Aggregate this node is.
-  Currently only works for class, struct, and union, but it can
-  easily be extended. If \a cap is true, the word is capitalised.
+  Currently recognizes class, struct, union, and namespace.
+  If \a cap is true, the word is capitalised.
  */
 QString Aggregate::typeWord(bool cap) const
 {
     if (cap) {
         switch (nodeType()) {
         case Node::Class:
-            return QLatin1String("Class");
+            return "Class"_L1;
         case Node::Struct:
-            return QLatin1String("Struct");
+            return "Struct"_L1;
         case Node::Union:
-            return QLatin1String("Union");
+            return "Union"_L1;
+        case Node::Namespace:
+            return "Namespace"_L1;
         default:
             break;
         }
     } else {
         switch (nodeType()) {
         case Node::Class:
-            return QLatin1String("class");
+            return "class"_L1;
         case Node::Struct:
-            return QLatin1String("struct");
+            return "struct"_L1;
         case Node::Union:
-            return QLatin1String("union");
+            return "union"_L1;
+        case Node::Namespace:
+            return "namespace"_L1;
         default:
             break;
         }
