@@ -200,8 +200,11 @@ int Generator::appendSortedQmlNames(Text &text, const Node *base, const QStringL
 QFile *Generator::openSubPageFile(const PageNode *node, const QString &fileName)
 {
     // Skip generating a warning for license attribution pages, as their source
-    // is generated by qtattributionsscanner and may potentially include duplicates
-    if (s_outFileNames.contains(fileName) && !node->isAttribution())
+    // is generated by qtattributionsscanner and may potentially include duplicates.
+    // NOTE: Depending on the value of the `QtParts` field in qt_attribution.json files,
+    // qtattributionsscanner may not use the \attribution QDoc command for the page
+    // (by design). Therefore, check also filename.
+    if (s_outFileNames.contains(fileName) && !node->isAttribution() && !fileName.contains("-attribution-"_L1))
         node->location().warning("Already generated %1 for this project"_L1.arg(fileName));
 
     QString path = outputDir() + QLatin1Char('/') + fileName;
@@ -719,6 +722,8 @@ void Generator::generateBody(const Node *node, CodeMarker *marker)
                 generateAddendum(node, Invokable, marker);
             if (fn->hasAssociatedProperties())
                 generateAddendum(node, AssociatedProperties, marker);
+            if (fn->hasOverloads() && fn->doc().hasOverloadCommand())
+                generateAddendum(node, OverloadNote, marker, AdmonitionPrefix::None);
         }
 
         // Generate warnings
@@ -1119,9 +1124,11 @@ QString Generator::formatSince(const Node *node)
 {
     QStringList since = node->since().split(QLatin1Char(' '));
 
-    // If there is only one argument, assume it is the Qt version number.
-    if (since.size() == 1)
-        return "Qt " + since[0];
+    // If there is only one argument, assume it is the product version number.
+    if (since.size() == 1) {
+        const QString productName = Config::instance().get(CONFIG_PRODUCTNAME).asString();
+        return productName.isEmpty() ? node->since() :  productName +  " " + since[0];
+    }
 
     // Otherwise, use the original <project> <version> string.
     return node->since();
@@ -1263,17 +1270,22 @@ void Generator::generateStatus(const Node *node, CodeMarker *marker)
   as the code marker.
 */
 void Generator::generateAddendum(const Node *node, Addendum type, CodeMarker *marker,
-                                 bool generateNote)
+                                 AdmonitionPrefix prefix)
 {
     Q_ASSERT(node && !node->name().isEmpty());
     Text text;
     text << Atom(Atom::DivLeft,
-            "class=\"admonition %1\""_L1.arg(generateNote ? u"note"_s : u"auto"_s));
+                 "class=\"admonition %1\""_L1.arg(prefix == AdmonitionPrefix::Note ? u"note"_s : u"auto"_s));
     text << Atom::ParaLeft;
 
-    if (generateNote) {
-        text  << Atom(Atom::FormattingLeft, ATOM_FORMATTING_BOLD)
-              << "Note: " << Atom(Atom::FormattingRight, ATOM_FORMATTING_BOLD);
+    switch (prefix) {
+    case AdmonitionPrefix::None:
+        break;
+    case AdmonitionPrefix::Note: {
+        text << Atom(Atom::FormattingLeft, ATOM_FORMATTING_BOLD)
+             << "Note: " << Atom(Atom::FormattingRight, ATOM_FORMATTING_BOLD);
+        break;
+        }
     }
 
     switch (type) {
@@ -1341,6 +1353,18 @@ void Generator::generateAddendum(const Node *node, Addendum type, CodeMarker *ma
         text << " bindings.";
         break;
     }
+    case OverloadNote:
+    {
+        const auto &args = node->doc().overloadList();
+        if (args.first().first.isEmpty()) {
+            text << "This is an overloaded function.";
+        } else {
+            text << "This function overloads "
+                 << Atom(Atom::AutoLink, args.first().first)
+                 << ".";
+        }
+        break;
+    }
     default:
         return;
     }
@@ -2229,4 +2253,69 @@ void Generator::unknownAtom(const Atom *atom)
                                     .arg(atom->typeString(), format()));
 }
 
+/*!
+ * Generate the CMake requisite for the node \a cn, i.e. the the find_package and target_link_libraries
+ * calls to use it.
+ *
+ * If only cmakepackage is set it will look like
+ *
+ * \badcode
+ * find_package(Foo REQUIRED)
+ * target_link_libraries(mytarget PRIVATE Foo:Foo)
+ * \endcode
+ *
+ * If no cmakepackage is set Qt6 is assumed.
+ *
+ * If cmakecomponent is set it will look like
+ *
+ * \badcode
+ * find_package(Qt6 REQUIRED COMPONENTS Bar)
+ * target_link_libraries(mytarget PRIVATE Qt6::Bar)
+ * \endcode
+ *
+ * If cmaketargetitem is set the item in target_link_libraries will be set accordingly
+ *
+ * \badcode
+ * find_package(Qt6 REQUIRED COMPONENTS Bar)
+ * target_link_libraries(mytarget PRIVATE My::Target)
+ * \endcode
+ *
+ * Returns a pair consisting of the find package line and link libraries line.
+ *
+ * If no sensible requisite can be created (i.e. both cmakecomponent and cmakepackage are unset)
+ * \c std::nullopt is returned.
+ */
+std::optional<std::pair<QString, QString>> Generator::cmakeRequisite(const CollectionNode *cn)
+{
+    if (!cn || (cn->cmakeComponent().isEmpty() && cn->cmakePackage().isEmpty())) {
+        return {};
+    }
+
+    const QString package =
+        cn->cmakePackage().isEmpty() ? "Qt" + QString::number(QT_VERSION_MAJOR) : cn->cmakePackage();
+
+    QString findPackageText;
+    if (cn->cmakeComponent().isEmpty()) {
+        findPackageText = "find_package(" + package + " REQUIRED)";
+    } else {
+        findPackageText = "find_package(" + package + " REQUIRED COMPONENTS " + cn->cmakeComponent() + ")";
+    }
+
+    QString targetText;
+    if (cn->cmakeTargetItem().isEmpty()) {
+        if (cn->cmakeComponent().isEmpty()) {
+            targetText = package + "::" + package;
+        } else {
+            targetText = package + "::" + cn->cmakeComponent();
+        }
+    } else {
+        targetText = cn->cmakeTargetItem();
+    }
+
+    const QString targetLinkLibrariesText = "target_link_libraries(mytarget PRIVATE " + targetText + ")";
+    const QStringList cmakeInfo { findPackageText, targetLinkLibrariesText };
+
+    return std::make_pair(findPackageText, targetLinkLibrariesText);
+}
+
 QT_END_NAMESPACE
