@@ -1,50 +1,16 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the tools applications of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
-#include "qtgradienteditor.h"
-#include "qtgradientstopscontroller.h"
+#include "qtgradienteditor_p.h"
+#include "qtgradientstopscontroller_p.h"
 #include "ui_qtgradienteditor.h"
 
 #include <QtWidgets/QButtonGroup>
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 class QtGradientEditorPrivate : public QObject
 {
     Q_OBJECT
@@ -73,20 +39,20 @@ public:
 
     void slotDetailsChanged(bool details);
 
-    void startLinearChanged(const QPointF &point);
-    void endLinearChanged(const QPointF &point);
-    void centralRadialChanged(const QPointF &point);
-    void focalRadialChanged(const QPointF &point);
+    void startLinearChanged(QPointF point);
+    void endLinearChanged(QPointF point);
+    void centralRadialChanged(QPointF point);
+    void focalRadialChanged(QPointF point);
     void radiusRadialChanged(qreal radius);
     void centralConicalChanged(const QPointF &point);
     void angleConicalChanged(qreal angle);
 
-    void setStartLinear(const QPointF &point);
-    void setEndLinear(const QPointF &point);
-    void setCentralRadial(const QPointF &point);
-    void setFocalRadial(const QPointF &point);
+    void setStartLinear(QPointF point);
+    void setEndLinear(QPointF point);
+    void setCentralRadial(QPointF point);
+    void setFocalRadial(QPointF point);
     void setRadiusRadial(qreal radius);
-    void setCentralConical(const QPointF &point);
+    void setCentralConical(QPointF point);
     void setAngleConical(qreal angle);
 
     void setType(QGradient::Type type);
@@ -171,9 +137,9 @@ QtGradientEditorPrivate::QtGradientEditorPrivate(QtGradientEditor *q)
     connect(m_gradientStopsController, &QtGradientStopsController::gradientStopsChanged,
             this, &QtGradientEditorPrivate::slotGradientStopsChanged);
 
-    QIcon iconLinear(QLatin1String(":/qt-project.org/qtgradienteditor/images/typelinear.png"));
-    QIcon iconRadial(QLatin1String(":/qt-project.org/qtgradienteditor/images/typeradial.png"));
-    QIcon iconConical(QLatin1String(":/qt-project.org/qtgradienteditor/images/typeconical.png"));
+    QIcon iconLinear(":/qt-project.org/qtgradienteditor/images/typelinear.png"_L1);
+    QIcon iconRadial(":/qt-project.org/qtgradienteditor/images/typeradial.png"_L1);
+    QIcon iconConical(":/qt-project.org/qtgradienteditor/images/typeconical.png"_L1);
 
     m_ui.typeComboBox->addItem(iconLinear, QtGradientEditor::tr("Linear"));
     m_ui.typeComboBox->addItem(iconRadial, QtGradientEditor::tr("Radial"));
@@ -193,9 +159,9 @@ QtGradientEditorPrivate::QtGradientEditorPrivate(QtGradientEditor *q)
     connect(m_ui.typeComboBox, &QComboBox::activated,
             this, &QtGradientEditorPrivate::slotTypeChanged);
 
-    QIcon iconPad(QLatin1String(":/qt-project.org/qtgradienteditor/images/spreadpad.png"));
-    QIcon iconRepeat(QLatin1String(":/qt-project.org/qtgradienteditor/images/spreadrepeat.png"));
-    QIcon iconReflect(QLatin1String(":/qt-project.org/qtgradienteditor/images/spreadreflect.png"));
+    QIcon iconPad(":/qt-project.org/qtgradienteditor/images/spreadpad.png"_L1);
+    QIcon iconRepeat(":/qt-project.org/qtgradienteditor/images/spreadrepeat.png"_L1);
+    QIcon iconReflect(":/qt-project.org/qtgradienteditor/images/spreadreflect.png"_L1);
 
     m_ui.spreadComboBox->addItem(iconPad, QtGradientEditor::tr("Pad"));
     m_ui.spreadComboBox->addItem(iconRepeat, QtGradientEditor::tr("Repeat"));
@@ -236,7 +202,7 @@ QtGradientEditorPrivate::QtGradientEditorPrivate(QtGradientEditor *q)
 
 QGradient QtGradientEditorPrivate::gradient() const
 {
-    QGradient *gradient = 0;
+    QGradient *gradient = nullptr;
     switch (m_ui.gradientWidget->gradientType()) {
         case QGradient::LinearGradient:
             gradient = new QLinearGradient(m_ui.gradientWidget->startLinear(),
@@ -739,25 +705,25 @@ void QtGradientEditorPrivate::slotAngleConicalChanged(double value)
     updateGradient(true);
 }
 
-void QtGradientEditorPrivate::startLinearChanged(const QPointF &point)
+void QtGradientEditorPrivate::startLinearChanged(QPointF point)
 {
     setStartLinear(point);
     updateGradient(true);
 }
 
-void QtGradientEditorPrivate::endLinearChanged(const QPointF &point)
+void QtGradientEditorPrivate::endLinearChanged(QPointF point)
 {
     setEndLinear(point);
     updateGradient(true);
 }
 
-void QtGradientEditorPrivate::centralRadialChanged(const QPointF &point)
+void QtGradientEditorPrivate::centralRadialChanged(QPointF point)
 {
     setCentralRadial(point);
     updateGradient(true);
 }
 
-void QtGradientEditorPrivate::focalRadialChanged(const QPointF &point)
+void QtGradientEditorPrivate::focalRadialChanged(QPointF point)
 {
     setFocalRadial(point);
     updateGradient(true);
@@ -781,7 +747,7 @@ void QtGradientEditorPrivate::angleConicalChanged(qreal angle)
     updateGradient(true);
 }
 
-void QtGradientEditorPrivate::setStartLinear(const QPointF &point)
+void QtGradientEditorPrivate::setStartLinear(QPointF point)
 {
     if (startLinearXSpinBox)
         startLinearXSpinBox->setValue(point.x());
@@ -789,7 +755,7 @@ void QtGradientEditorPrivate::setStartLinear(const QPointF &point)
         startLinearYSpinBox->setValue(point.y());
 }
 
-void QtGradientEditorPrivate::setEndLinear(const QPointF &point)
+void QtGradientEditorPrivate::setEndLinear(QPointF point)
 {
     if (endLinearXSpinBox)
         endLinearXSpinBox->setValue(point.x());
@@ -797,7 +763,7 @@ void QtGradientEditorPrivate::setEndLinear(const QPointF &point)
         endLinearYSpinBox->setValue(point.y());
 }
 
-void QtGradientEditorPrivate::setCentralRadial(const QPointF &point)
+void QtGradientEditorPrivate::setCentralRadial(QPointF point)
 {
     if (centralRadialXSpinBox)
         centralRadialXSpinBox->setValue(point.x());
@@ -805,7 +771,7 @@ void QtGradientEditorPrivate::setCentralRadial(const QPointF &point)
         centralRadialYSpinBox->setValue(point.y());
 }
 
-void QtGradientEditorPrivate::setFocalRadial(const QPointF &point)
+void QtGradientEditorPrivate::setFocalRadial(QPointF point)
 {
     if (focalRadialXSpinBox)
         focalRadialXSpinBox->setValue(point.x());
@@ -819,7 +785,7 @@ void QtGradientEditorPrivate::setRadiusRadial(qreal radius)
         radiusRadialSpinBox->setValue(radius);
 }
 
-void QtGradientEditorPrivate::setCentralConical(const QPointF &point)
+void QtGradientEditorPrivate::setCentralConical(QPointF point)
 {
     if (centralConicalXSpinBox)
         centralConicalXSpinBox->setValue(point.x());
